@@ -427,6 +427,14 @@ insert_ps_header(FILE * fp, bool privacy)
 		fprintf(fp, "%%%%CreationDate: %s", asctime(localtime(&sec)));
 		fprintf(fp, "%%%%Pages: (atend)\n");
 		fprintf(fp, "%%%%BoundingBox: (atend)\n");
+
+                extern rectangle _bounding_box;
+                fprintf(fp, "%% trial bounding box  %f %f %f %f\n", 
+                        _bounding_box.llx(),
+                        _bounding_box.lly(),
+                        _bounding_box.urx(),
+                        _bounding_box.ury());
+
 		fprintf(fp, "%%%%TemplateBox: %d %d %d %d\n",
 			0, 0, (int) (8.5 * 72.0), (int) (11.0 * 72.0));
 		fprintf(fp, "%%%%DocumentFonts: (atend)\n");
@@ -990,6 +998,15 @@ gr_end(const char *filename)
 static void
 close_ps_file(FILE * fp)
 {
+#if 0
+        extern rectangle _bounding_box;
+        printf("FILE %s | %d | close_ps_file() | bounding box LLx LLy URx URy %d %d %d %d\n", 
+               __FILE__, __LINE__,
+               int(_bounding_box.llx() * PT_PER_CM),
+               int(_bounding_box.lly() * PT_PER_CM),
+               int(_bounding_box.urx() * PT_PER_CM),
+               int(_bounding_box.ury() * PT_PER_CM));
+#endif
 	fclose(fp);
 	_grNeedBegin = true;
 }
@@ -1000,13 +1017,14 @@ gr_error(const char *lab)
 {
 	sprintf(grTempString, "\nFATAL error: %s\n", lab);
 	gr_textput(grTempString);
-	abort_gri();
+        abort_gri();
 }
 
 void
 abort_gri()
 {
-	abort();
+	//abort();
+        exit(1);
 }
 
 /*
@@ -1135,19 +1153,22 @@ gr_moveto_cm(double x_cm, double y_cm)
 	double y_pt = y_cm * PT_PER_CM;
 	extern FILE    *_grPS;
 	// take care of postscript stuff
-	if (_grWritePS) {
-		if (_grPathExists) {	// a path exists
-			fprintf(_grPS, PS_stroke);
-			fprintf(_grPS, PS_weak_newpath);
-			fprintf(_grPS, PS_moveto, x_pt, y_pt);
-		} else {		// make new path
-			_grPathExists = true;
-			fprintf(_grPS, PS_weak_newpath);
-			fprintf(_grPS, PS_moveto, x_pt, y_pt);
-		}
-	}
-	_grCurrentPoint_x = x_pt;
-	_grCurrentPoint_y = y_pt;
+	extern output_file_type _output_file_type;
+	if (_output_file_type == postscript) {
+                if (_grWritePS) {
+                        if (_grPathExists) {	// a path exists
+                                fprintf(_grPS, PS_stroke);
+                                fprintf(_grPS, PS_weak_newpath);
+                                fprintf(_grPS, PS_moveto, x_pt, y_pt);
+                        } else {		// make new path
+                                _grPathExists = true;
+                                fprintf(_grPS, PS_weak_newpath);
+                                fprintf(_grPS, PS_moveto, x_pt, y_pt);
+                        }
+                }
+                _grCurrentPoint_x = x_pt;
+                _grCurrentPoint_y = y_pt;
+        }
 }
 
 // See gr_onxpage_cm() -- see if point is on the page
@@ -1294,7 +1315,8 @@ gr_reopen_postscript(const char *new_name)
 		return false;		// couldn't open it
 	while (!feof(_grPS)) {
 		i++;
-		fgets(grTempString, _grTempStringLEN, _grPS);
+		if (NULL == fgets(grTempString, _grTempStringLEN, _grPS))
+		        break;
 		if (feof(_grPS))
 			break;
 		fputs(grTempString, new_file);
@@ -1329,6 +1351,15 @@ gr_save_postscript(const char *PS_name, int normal_scale)
 		sprintf(grTempString, "Can't open postscript file `%s'", PS_name);
 		gr_Error(grTempString);
 	}
+
+        extern rectangle _bounding_box;
+        printf("%s%d gr_save_postscript() ... bounding box  %f %f %f %f\n",
+               __FILE__, __LINE__,
+               _bounding_box.llx(),
+               _bounding_box.lly(),
+               _bounding_box.urx(),
+               _bounding_box.ury());
+        
 	if (normal_scale) {
 		double          old_grMagx = _grMagx, old_grMagy = _grMagy;
 		double          old_grOriginx = _grOriginx, old_grOriginy = _grOriginy;
@@ -1344,7 +1375,8 @@ gr_save_postscript(const char *PS_name, int normal_scale)
 	} else
 		insert_ps_header(PS_file, true);
 	while (!feof(_grPS)) {
-		fgets(grTempString, _grTempStringLEN, _grPS);
+	        if (NULL == fgets(grTempString, _grTempStringLEN, _grPS))
+		        break;
 		if (feof(_grPS))
 			break;
 		fputs(grTempString, PS_file);
@@ -1360,17 +1392,20 @@ skip_ps_header(FILE * PSfile)
 	/*
 	 * Skip header if it exists
 	 */
-	fgets(S, 256, PSfile);
+	if (NULL == fgets(S, 256, PSfile))
+		gr_Error("PostScript file is empty");
 	if (feof(PSfile))
 		gr_Error("PostScript file is empty");
 	if (!strcmp(S, "%!\n")) {	/* old-style */
-		fgets(S, 256, PSfile);
+		if (NULL == fgets(S, 256, PSfile))
+			gr_Error("PostScript file is nearly empty");
 		if (feof(PSfile))
 			gr_Error("PostScript file is nearly empty");
 		if (1 == sscanf(&S[1], "%d header lines follow\n",
 				&header_lines)) {
 			while (header_lines-- > 0) {
-				fgets(S, 256, PSfile);
+				if (NULL == fgets(S, 256, PSfile))
+					gr_Error("badly formed (old-style) header");
 				if (feof(PSfile))
 					gr_Error("badly formed (old-style) header");
 			}
@@ -1379,7 +1414,8 @@ skip_ps_header(FILE * PSfile)
 		}
 	} else if (!strcmp(S, "%!PS-Adobe-1.0\n"))	/* new-style */
 		while (strncmp(S, "%%Page:", 7)) {
-			fgets(S, 256, PSfile);
+			if (NULL == fgets(S, 256, PSfile))
+				gr_Error("badly formed header");
 			if (feof(PSfile))
 				gr_Error("badly formed header");
 		}
@@ -1847,32 +1883,37 @@ gr_set_clip_ps_off()
 void
 gr_set_clip_ps_rect(double ll_x_pt, double ll_y_pt, double ur_x_pt, double ur_y_pt)
 {
-	if (_clipping_postscript) {
-		fprintf(_grPS, "S Q %% turn existing clipping off since user forgot to\n");
-		check_psfile();
-	}
-	_clip_ps_xleft = SMALLER_ONE(ll_x_pt, ur_x_pt);
-	_clip_ps_ybottom = SMALLER_ONE(ll_y_pt, ur_y_pt);
-	_clip_ps_xright = LARGER_ONE(ll_x_pt, ur_x_pt);
-	_clip_ps_ytop = LARGER_ONE(ll_y_pt, ur_y_pt);
-
-/*DEK*/	//printf("DEBUG: am setting clip to xl=%f  xr=%f  yb=%f  yt=%f\n", _clip_ps_xleft, _clip_ps_xright, _clip_ps_ybottom, _clip_ps_ytop);
-
-/*DEK*/
-// why do I not have "Q" to finish it off?
-// why do I not have "W*" to finish it off?
-/*DEK*/
-	fprintf(_grPS, "q n\n");
-	fprintf(_grPS, "%f %f moveto\n", _clip_ps_xleft, _clip_ps_ybottom);
-	fprintf(_grPS, "%f %f lineto\n", _clip_ps_xright, _clip_ps_ybottom);
-	fprintf(_grPS, "%f %f lineto\n", _clip_ps_xright, _clip_ps_ytop);
-	fprintf(_grPS, "%f %f lineto\n", _clip_ps_xleft, _clip_ps_ytop);
-	fprintf(_grPS, "h W\n");
-	fprintf(_grPS, "n %% turn clipping on\n");
-	check_psfile();
-	_clipping_is_postscript_rect = true;
-	//printf("%s:%d set RECT ps clip\n",__FILE__,__LINE__);
-	_clipping_postscript = true;
+	extern output_file_type _output_file_type;
+	if (_output_file_type == svg) {
+                warning("cannot yet clip in svg files");
+        } else if (_output_file_type == postscript) {
+                if (_clipping_postscript) {
+                        fprintf(_grPS, "S Q %% turn existing clipping off since user forgot to\n");
+                        check_psfile();
+                }
+                _clip_ps_xleft = SMALLER_ONE(ll_x_pt, ur_x_pt);
+                _clip_ps_ybottom = SMALLER_ONE(ll_y_pt, ur_y_pt);
+                _clip_ps_xright = LARGER_ONE(ll_x_pt, ur_x_pt);
+                _clip_ps_ytop = LARGER_ONE(ll_y_pt, ur_y_pt);
+                
+                /*DEK*/	//printf("DEBUG: am setting clip to xl=%f  xr=%f  yb=%f  yt=%f\n", _clip_ps_xleft, _clip_ps_xright, _clip_ps_ybottom, _clip_ps_ytop);
+                
+                /*DEK*/
+                // why do I not have "Q" to finish it off?
+                // why do I not have "W*" to finish it off?
+                /*DEK*/
+                fprintf(_grPS, "q n\n");
+                fprintf(_grPS, "%f %f moveto\n", _clip_ps_xleft, _clip_ps_ybottom);
+                fprintf(_grPS, "%f %f lineto\n", _clip_ps_xright, _clip_ps_ybottom);
+                fprintf(_grPS, "%f %f lineto\n", _clip_ps_xright, _clip_ps_ytop);
+                fprintf(_grPS, "%f %f lineto\n", _clip_ps_xleft, _clip_ps_ytop);
+                fprintf(_grPS, "h W\n");
+                fprintf(_grPS, "n %% turn clipping on\n");
+                check_psfile();
+                _clipping_is_postscript_rect = true;
+                //printf("%s:%d set RECT ps clip\n",__FILE__,__LINE__);
+                _clipping_postscript = true;
+        }
 }
 
 void
