@@ -731,7 +731,7 @@ pwd()
 #if HAVE_GETCWD
 	static char msg[1024];
 	if (NULL == getcwd(msg, 1024))
-		return "";
+		return (char *)"";
 	else
 		return msg;
 #elif defined(VMS)		/* vms version braindead */
@@ -770,7 +770,7 @@ char*
 egetenv(const char *s)
 {
 #if defined(HAVE_GETENV)
-	char *rval = "";
+	char *rval = (char *)"";
 #endif
 	if (!strcmp(s, "PWD")) {
 		return (char *) pwd();
@@ -778,55 +778,55 @@ egetenv(const char *s)
 #if defined(HAVE_GETENV)
 		rval = (char *)getenv(s);
 		if (rval == NULL)
-			return "";
+			return (char *)"";
 		else
 			return rval;
 #else
-		return "unknown";
+		return (char *)"unknown";
 #endif
 	} else if (!strcmp(s, "SYSTEM")) {
 #if defined(VMS)
-		return "vax";
+		return (char *)"vax";
 #elif defined(MSDOS)
-		return "msdos";
+		return (char *)"msdos";
 #else
-		return "unix";
+		return (char *)"unix";
 #endif
 	} else if (!strcmp(s, "HOST")) {
 #if defined(HAVE_GETENV)
 		rval = (char *)getenv(s);
 		if (rval == NULL)
-			return "";
+			return (char *)"";
 		else
 			return rval;
 #else
-		return "unknown";
+		return (char *)"unknown";
 #endif
 	} else if (!strcmp(s, "HOME")) {
 #if defined(HAVE_GETENV)
 		rval = (char *)getenv(s);
 		if (rval == NULL)
-			return "";
+			return (char *)"";
 		else
 			return rval;
 #else
-		return "unknown";
+		return (char *)"unknown";
 #endif
 	} else if (!strcmp(s, "PAGER")) {
 #if defined(HAVE_GETENV)
 		rval = (char *)getenv(s);
 		if (rval == NULL)
-			return "";
+			return (char *)"";
 		else
 			return rval;
 #else
-		return "unknown";
+		return (char *)"unknown";
 #endif
 	} else if (!strcmp(s, "GRIINPUTS")) {
 #if defined(HAVE_GETENV)
 		rval = (char *)getenv(s);
 		if (rval == NULL)
-			return "";
+			return (char *)"";
 		else
 			return rval;
 #else
@@ -836,7 +836,7 @@ egetenv(const char *s)
 #if defined(HAVE_GETENV)
 		rval = (char *)getenv(s);
 		if (rval == NULL)
-			return "";
+			return (char*)"";
 		else
 			return rval;
 #else
@@ -1962,6 +1962,9 @@ void
 bounding_box_update(const rectangle& box)
 {
 	// Only process if supplied bbox is nonzero in size
+#if 0
+        printf("updating bounding box %f < x < %f     %f < y < %f\n", box.llx(), box.urx(), box.lly(), box.ury());
+#endif
 	if (box.llx()    != box.urx()
 	    || box.lly() != box.ury()) {
 		// If have existing bbox, see if this lies outside ...
@@ -2343,21 +2346,66 @@ un_double_quote(std::string& word)
 void
 fix_negative_zero(std::string& number) // change e.g. "-0" to "0", for axes
 {
-	bool is_zero = true;
-	unsigned int i = 0;
-	for (; i < number.size(); i++)
-		if (number[i] != ' ')
+        //#define DEBUG_FIX_NEGATIVE_ZERO
+#ifdef DEBUG_FIX_NEGATIVE_ZERO
+        number = "-" + number;
+        printf("called fix_negative_zero(%s) [%s]\n", number.c_str(), number.c_str());
+#endif
+	unsigned int i;
+        unsigned size = number.size();
+        // find first non-blank character
+        unsigned start = 0;
+	for (i = 0; i < size; i++) {
+		if (number[i] != ' ') {
+                        start = i;
 			break;
-	if (i == number.size() || number[i] != '-')
+                }
+        }
+	if (i == size || number[i] != '-')
 		return;
-	for (i++; i < number.size(); i++) {
-		if (number[i] != '0' && number[i] != '.') {
-			is_zero = false;
-			break;
-		}
-	}
-	if (is_zero)
-		number.STRINGERASE(0, 1);
+#ifdef DEBUG_FIX_NEGATIVE_ZERO
+        printf("    first character is a minus.  start=%d\n    ", start);
+#endif
+        // find last digit
+        unsigned end = size - 1;
+        for (i = end; i > start; i--) {
+#ifdef DEBUG_FIX_NEGATIVE_ZERO
+                printf("c[%2d]='%c' ", i, number[i]);
+#endif
+                if (isdigit(number[i]) || number[i] == '.') {
+                        end = i;
+#ifdef DEBUG_FIX_NEGATIVE_ZERO
+                        printf("\n");
+#endif
+                        break;
+                }
+        }
+#ifdef DEBUG_FIX_NEGATIVE_ZERO
+                        printf("    end=%d\n", end);
+#endif
+        std::string portion = number.substr(start + 1, end - start); // just digits or decimals
+#ifdef DEBUG_FIX_NEGATIVE_ZERO
+        printf("    portion='%s'\n", portion.c_str());
+#endif
+        // The 'portion' is now a middle portion consisting of digits and decimals
+	bool is_zero = true;
+        for (i = 0; i < portion.size(); i++) {
+                if (!(portion[i] == '0' || portion[i] == '.')) {
+                        is_zero = false;
+                        break;
+                }
+        }
+        printf("    is_zero=%d\n", is_zero);
+	if (is_zero) {
+#ifdef DEBUG_FIX_NEGATIVE_ZERO
+		printf("    ERASING at start=%d\n", start);
+#endif
+                number[start] = ' ';
+        }
+#ifdef DEBUG_FIX_NEGATIVE_ZERO
+        printf("    returning '%s'\n", number.c_str());
+#endif
+#undef DEBUG_FIX_NEGATIVE_ZERO
 }
 
 bool
